SelectStatement class
- Inheritance
-
- Object
- AstNode
- Statement
- CrudStatement
- BaseSelectStatement
- SelectStatement
- Implemented types
- Available extensions
Constructors
-
SelectStatement({WithClause? withClause, bool distinct = false, required List<
ResultColumn> columns, Queryable? from, Expression? where, GroupBy? groupBy, List<NamedWindowDeclaration> windowDeclarations = const [], OrderByBase? orderBy, LimitBase? limit})
Properties
-
allDescendants
→ Iterable<
AstNode> -
Recursively returns all descendants of this node, e.g. its children, their
children and so on. The tree will be pre-order traversed.
no setterinherited
-
childNodes
→ Iterable<
AstNode> -
All direct children of this node.
no setteroverride
-
columns
↔ List<
ResultColumn> -
getter/setter pair
- distinct → bool
-
final
- first ↔ Token?
-
The first token that appears in this node. This information is not set for
all nodes.
getter/setter pairinherited
- firstPosition → int
-
The first position of this entity, as an zero-based offset in the file it
was read from.
no setterinherited
- from ↔ Queryable?
-
The table, join clause or subquery appearing in the
FROMclause.getter/setter pairoverride-getter - groupBy ↔ GroupBy?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSpan → bool
-
Whether this entity has a source span associated with it.
no setterinherited
- last ↔ Token?
-
The last token that appears in this node. This information is not set for
all nodes.
getter/setter pairinherited
- lastPosition → int
-
The (exclusive) last index of this entity in the source.
no setterinherited
- length → int
-
Available on SyntacticEntity, provided by the SyntacticLengthExtension extension
The length of this entity, in characters.no setter - limit ↔ LimitBase?
-
getter/setter pair
- optionalScope → ReferenceScope?
-
no setterinherited
- orderBy ↔ OrderByBase?
-
getter/setter pair
- parent ↔ AstNode?
-
The parent of this node, or null if this is the root node. Will be set
by the analyzer after the tree has been parsed.
getter/setter pairinherited
-
parents
→ Iterable<
AstNode> -
Returns all parents of this node up to the root. If this node is the root,
the iterable will be empty.
no setterinherited
-
resolvedColumns
↔ List<
Column> ? -
The resolved list of columns returned by this select statements. Not
available from the parse tree, will be set later by the analyzer.
getter/setter pairinherited
- resultSet → ResultSet
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope ↔ ReferenceScope
-
The ReferenceScope, which contains available tables, column references
and functions for this node.
getter/setter pairinherited
-
selfAndDescendants
→ Iterable<
AstNode> -
Returns an iterable that fields yields this node, followed by
allDescendants.
no setterinherited
-
selfAndParents
→ Iterable<
AstNode> -
Returns an iterable containing
thisnode and all parents.no setterinherited - semicolon ↔ Token?
-
getter/setter pairinherited
- span → FileSpan?
-
The piece of text forming this syntactic entity.
no setterinherited
- statementScope → StatementScope
-
no setterinherited
- synthetic ↔ bool
-
Whether this entity is synthetic, meaning that it doesn't appear in the
actual source.
getter/setter pairinherited
- table → Queryable?
-
The primary table this statement operates on. This is the part after the
FROMfor select and delete statements, the part after theINTOfor inserts and the name after theUPDATEfor updates.no setteroverride - visibleToChildren → bool
-
Whether this referencable is still visible in child scopes. This doesn't
apply to many things, basically only to tables.
no setterinherited
- where ↔ Expression?
-
getter/setter pairoverride-getter
-
windowDeclarations
↔ List<
NamedWindowDeclaration> -
getter/setter pair
- withClause ↔ WithClause?
-
getter/setter pairinherited
Methods
-
accept<
A, R> (AstVisitor< A, R> visitor, A arg) → R -
Calls the appropriate method on the
visitorto make it recognize this node.override -
acceptWithoutArg<
R> (AstVisitor< void, R> visitor) → R -
Like accept, but without an argument.
inherited
-
contentEquals(
AstNode other) → bool -
Whether the content of this node is equal to the
othernode of the same type. The "content" refers to anything stored only in this node, children are ignored.inherited -
enclosingOfType<
T extends AstNode> () → T? -
Finds the first element in selfAndParents of the type
T.inherited -
findColumn(
String name) → Column? -
inherited
-
isChildOf(
AstNode other) → bool -
inherited
-
meta<
T> () → T? -
Returns the metadata of type
Tthat might have been set on this node, or null if none was found. Nodes can have arbitrary annotations on them set viasetMetaand obtained viameta. This mechanism is used to, for instance, attach variable scopes to a subtree.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setMeta<
T> (T value) → void -
Sets the metadata of type
Tto the specifiedvalue. Nodes can have arbitrary annotations on them set viasetMetaand obtained viameta. This mechanism is used to, for instance, attach variable scopes to a subtree.inherited -
setSpan(
Token first, Token last) → void -
Sets the AstNode.first and AstNode.last property in one go.
inherited
-
toSql(
) → String -
Available on AstNode, provided by the NodeToText extension
Obtains a textual representation for AST nodes. -
toString(
) → String -
A string representation of this object.
inherited
-
transformChildren<
A> (Transformer< A> transformer, A arg) → void -
Transforms children of this node by invoking
transformerwith the argumentarg.override -
unalias(
) → ResultSet -
Available on ResultSet, provided by the UnaliasResultSet extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited