TableReference class
A table. The first path in https://www.sqlite.org/syntax/table-or-subquery.html
This is both referencable (if we have SELECT * FROM table t), other parts of the select statement can access "t") and a reference owner (the table).
Note that this doesn't necessarily resolve to a result set. It could also resolve to a common table expression or anything else defining a result set.
- Inheritance
-
- Object
- AstNode
- Queryable
- TableOrSubquery
- TableReference
- Implemented types
- Mixed-in types
- Available extensions
Constructors
- TableReference(String tableName, {AliasClause? as, String? schemaName})
Properties
-
allDescendants
→ Iterable<
AstNode> -
Recursively returns all descendants of this node, e.g. its children, their
children and so on. The tree will be pre-order traversed.
no setterinherited
- as ↔ AliasClause?
-
getter/setter pairoverride-getter
- availableResultSet ↔ ResultSetAvailableInStatement?
-
The result set that this node made available, if any
getter/setter pairinherited
-
childNodes
→ Iterable<
AstNode> -
All direct children of this node.
no setteroverride
- first ↔ Token?
-
The first token that appears in this node. This information is not set for
all nodes.
getter/setter pairinherited
- firstPosition → int
-
The first position of this entity, as an zero-based offset in the file it
was read from.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSpan → bool
-
Whether this entity has a source span associated with it.
no setterinherited
- last ↔ Token?
-
The last token that appears in this node. This information is not set for
all nodes.
getter/setter pairinherited
- lastPosition → int
-
The (exclusive) last index of this entity in the source.
no setterinherited
- length → int
-
Available on SyntacticEntity, provided by the SyntacticLengthExtension extension
The length of this entity, in characters.no setter - optionalScope → ReferenceScope?
-
no setterinherited
- parent ↔ AstNode?
-
The parent of this node, or null if this is the root node. Will be set
by the analyzer after the tree has been parsed.
getter/setter pairinherited
-
parents
→ Iterable<
AstNode> -
Returns all parents of this node up to the root. If this node is the root,
the iterable will be empty.
no setterinherited
- resolved ↔ Referencable?
-
The resolved reference, or null if it hasn't been resolved yet.
getter/setter pairinherited
- resultSet → ResultSet?
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaName → String?
-
final
- schemaNameToken ↔ IdentifierToken?
-
getter/setter pair
- scope ↔ ReferenceScope
-
The ReferenceScope, which contains available tables, column references
and functions for this node.
getter/setter pairinherited
-
selfAndDescendants
→ Iterable<
AstNode> -
Returns an iterable that fields yields this node, followed by
allDescendants.
no setterinherited
-
selfAndParents
→ Iterable<
AstNode> -
Returns an iterable containing
thisnode and all parents.no setterinherited - span → FileSpan?
-
The piece of text forming this syntactic entity.
no setterinherited
- statementScope → StatementScope
-
no setterinherited
- synthetic ↔ bool
-
Whether this entity is synthetic, meaning that it doesn't appear in the
actual source.
getter/setter pairinherited
- tableName → String
-
final
- tableNameToken ↔ IdentifierToken?
-
getter/setter pair
- visibleToChildren → bool
-
Whether this referencable is still visible in child scopes. This doesn't
apply to many things, basically only to tables.
no setteroverride
Methods
-
accept<
A, R> (AstVisitor< A, R> visitor, A arg) → R -
Calls the appropriate method on the
visitorto make it recognize this node.override -
acceptWithoutArg<
R> (AstVisitor< void, R> visitor) → R -
Like accept, but without an argument.
inherited
-
contentEquals(
AstNode other) → bool -
Whether the content of this node is equal to the
othernode of the same type. The "content" refers to anything stored only in this node, children are ignored.inherited -
enclosingOfType<
T extends AstNode> () → T? -
Finds the first element in selfAndParents of the type
T.inherited -
isChildOf(
AstNode other) → bool -
inherited
-
meta<
T> () → T? -
Returns the metadata of type
Tthat might have been set on this node, or null if none was found. Nodes can have arbitrary annotations on them set viasetMetaand obtained viameta. This mechanism is used to, for instance, attach variable scopes to a subtree.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setMeta<
T> (T value) → void -
Sets the metadata of type
Tto the specifiedvalue. Nodes can have arbitrary annotations on them set viasetMetaand obtained viameta. This mechanism is used to, for instance, attach variable scopes to a subtree.inherited -
setSpan(
Token first, Token last) → void -
Sets the AstNode.first and AstNode.last property in one go.
inherited
-
toSql(
) → String -
Available on AstNode, provided by the NodeToText extension
Obtains a textual representation for AST nodes. -
toString(
) → String -
A string representation of this object.
inherited
-
transformChildren<
A> (Transformer< A> transformer, A arg) → void -
Transforms children of this node by invoking
transformerwith the argumentarg.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited