CaseInsensitiveMap<K extends String?, T> class

A map from strings to T where keys are compared without case sensitivity.

Inheritance

Constructors

CaseInsensitiveMap()
CaseInsensitiveMap.of(Map<K, T> other)
factory

Properties

entries → Iterable<MapEntry<K, T>>
The map entries of this Map.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty → bool
Whether there is at least one key/value pair in the map.
no setterinherited
keys → Iterable<K>
The keys of this Map.
no setteroverride
length → int
The number of key/value pairs in the map.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → Iterable<T>
The values of this Map.
no setterinherited

Methods

addAll(Map<K, T> other) → void
Adds all key/value pairs of other to this map.
inherited
addEntries(Iterable<MapEntry<K, T>> newEntries) → void
Adds all key/value pairs of newEntries to this map.
inherited
cast<RK, RV>() → Map<RK, RV>
Provides a view of this map as having RK keys and RV instances, if necessary.
inherited
clear() → void
Removes all entries from the map.
override
containsKey(Object? key) → bool
Whether this map contains the given key.
override
containsValue(Object? value) → bool
Whether this map contains the given value.
inherited
forEach(void action(K key, T value)) → void
Applies action to each key/value pair of the map.
inherited
map<K2, V2>(MapEntry<K2, V2> transform(K key, T value)) → Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(K key, T ifAbsent()) → T
Look up the value of key, or add a new entry if it isn't there.
inherited
remove(Object? key) → T?
Removes key and its associated value, if present, from the map.
override
removeWhere(bool test(K key, T value)) → void
Removes all entries of this map that satisfy the given test.
inherited
toString() → String
A string representation of this object.
inherited
update(K key, T update(T value), {T ifAbsent()?}) → T
Updates the value for the provided key.
inherited
updateAll(T update(K key, T value)) → void
Updates all values.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](Object? key) → T?
The value for the given key, or null if key is not in the map.
override
operator []=(K key, T value) → void
Associates the key with the given value.
override