TableWrite class

A write to a table or view as found while analyzing a statement.

While views normally can't be written to, sqlite3 supports INSTEAD OF triggers allowing other statements to be executed when running writes on views.

Constructors

TableWrite(NamedResultSet table, UpdateKind kind)

Properties

hashCode → int
The hash code for this object.
no setteroverride
kind → UpdateKind
What kind of update was found (e.g. insert, update or delete).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → NamedResultSet
The table that a statement might write to when run.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override