PowerSyncSqliteExtension class final
Provides static analysis support for the PowerSync SQLite core extension.
This provides the powersync_crud eponymous virtual table to store local
mutation as well as some JSON / UUID helper functions.
- Implemented types
Constructors
- PowerSyncSqliteExtension()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
SqlEngine engine) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited